/*
 * Copyright (c) Huawei Technologies Co., Ltd. 2020-2024. All rights reserved.
 */

#ifndef DPC_IMPL_TYPE_RMRDEDGELFTGEOMETRY_H
#define DPC_IMPL_TYPE_RMRDEDGELFTGEOMETRY_H

#include <cfloat>
#include <cmath>
#include "impl_type_float.h"
#include "impl_type_boolean.h"

namespace dpc {
struct RMRdEdgeLftgeometry {
    ::Float c0_lrdedge{ 0.0F };
    ::Float c1_lrdedge{ 0.0F };
    ::Float c2_lrdedge{ 0.0F };
    ::Float c3_lrdedge{ 0.0F };
    ::Float start_rnge_lrdedge{ 0.0F };
    ::Float end_rnge_lrdedge{ 0.0F };
    ::Float probability_lrdedge{ 0.0F };
    ::Boolean valid_lrdedge{ false };

    static bool IsPlane()
    {
        return true;
    }


    using IsEnumerableTag = void;
    template<typename F>
    void enumerate(F& fun)
    {
        fun(c0_lrdedge);
        fun(c1_lrdedge);
        fun(c2_lrdedge);
        fun(c3_lrdedge);
        fun(start_rnge_lrdedge);
        fun(end_rnge_lrdedge);
        fun(probability_lrdedge);
        fun(valid_lrdedge);
    }

    template<typename F>
    void enumerate(F& fun) const
    {
        fun(c0_lrdedge);
        fun(c1_lrdedge);
        fun(c2_lrdedge);
        fun(c3_lrdedge);
        fun(start_rnge_lrdedge);
        fun(end_rnge_lrdedge);
        fun(probability_lrdedge);
        fun(valid_lrdedge);
    }

    template<typename F>
    void enumerate_internal(F& fun)
    {
        fun("c0_lrdedge", c0_lrdedge);
        fun("c1_lrdedge", c1_lrdedge);
        fun("c2_lrdedge", c2_lrdedge);
        fun("c3_lrdedge", c3_lrdedge);
        fun("start_rnge_lrdedge", start_rnge_lrdedge);
        fun("end_rnge_lrdedge", end_rnge_lrdedge);
        fun("probability_lrdedge", probability_lrdedge);
        fun("valid_lrdedge", valid_lrdedge);
    }

    template<typename F>
    void enumerate_internal(F& fun) const
    {
        fun("c0_lrdedge", c0_lrdedge);
        fun("c1_lrdedge", c1_lrdedge);
        fun("c2_lrdedge", c2_lrdedge);
        fun("c3_lrdedge", c3_lrdedge);
        fun("start_rnge_lrdedge", start_rnge_lrdedge);
        fun("end_rnge_lrdedge", end_rnge_lrdedge);
        fun("probability_lrdedge", probability_lrdedge);
        fun("valid_lrdedge", valid_lrdedge);
    }

    friend bool operator==(const ::dpc::RMRdEdgeLftgeometry& lhs, const ::dpc::RMRdEdgeLftgeometry& rhs) noexcept
    {
        return (fabs(static_cast<double>(lhs.c0_lrdedge - rhs.c0_lrdedge)) < DBL_EPSILON) && (fabs(static_cast<double>(lhs.c1_lrdedge - rhs.c1_lrdedge)) < DBL_EPSILON) && (fabs(static_cast<double>(lhs.c2_lrdedge - rhs.c2_lrdedge)) < DBL_EPSILON) && (fabs(static_cast<double>(lhs.c3_lrdedge - rhs.c3_lrdedge)) < DBL_EPSILON) && (fabs(static_cast<double>(lhs.start_rnge_lrdedge - rhs.start_rnge_lrdedge)) < DBL_EPSILON) && (fabs(static_cast<double>(lhs.end_rnge_lrdedge - rhs.end_rnge_lrdedge)) < DBL_EPSILON) && (fabs(static_cast<double>(lhs.probability_lrdedge - rhs.probability_lrdedge)) < DBL_EPSILON) && (lhs.valid_lrdedge == rhs.valid_lrdedge);
    }
};
} // namespace dpc


#endif // DPC_IMPL_TYPE_RMRDEDGELFTGEOMETRY_H
